# EAGLER

EAGLER is a scaffolding tool for long reads. The scaffolder takes as input a draft genome created by
 any NGS assembler and a set of long reads. The long reads are used to extend the contigs present in
 the NGS draft and possibly join overlapping contigs. EAGLER supports both PacBio and Oxford
 Nanopore reads.

## Documentation

Please check the [links](links.md) file for links to datasets and additional information on the
 alignment toolbox used by the scaffolder.

## Usage

To run the tool please use the command format shown below:

	eagler [options] <draft_genome.fasta> <long_reads.fasta> <output_prefix/output_dir>

The implementation will automatically detect the number of hardware threads supported by the system.

The default configuration, i.e. no command line options, expects PacBio reads as input. The
 underlying aligner will be set to BWA and the Local/Global Realign algorithm will be used to extend
 the contigs.

To get a detailed view of the available options please run:

	eagler -h

###Arguments:

 1. **draft\_genome.fasta**: FASTA file containing the draft genome created by some NGS pipeline
 2. **long\_reads.fasta**: FASTA file containing long reads to be used in the scaffolding
 3. **output\_prefix/output\_dir**: the prefix to be added to the output files or the directory where the scaffolder should store the results

### Examples:

**1)**	`eagler -x pacbio -t 16 draft.fasta reads.fasta output_dir/`

The above command will run the scaffolder over the draft genome `draft.fasta` using 24 parallel threads. The input for this example is a set of PacBio long reads from the `reads.fasta` file. The output of the scaffolder will consist of 3 files stored in the `output_dir` directory:

| Output File                   | Content                                                         |
| ----------------------------: | :-------------------------------------------------------------- |
| output_dir/contigs.fasta      | Contigs from the draft genome extended by the scaffolder        |
| output_dir/extensions.fasta   | Left and right extensions for each contig in the draft          |
| output_dir/scaffolds.fasta    | Final scaffolds created by merging overlapping extended contigs |

**2)** `eagler -g -x ont draft.fasta ont_reads.fasta example_2`

The above command will run the scaffolder over the draft genome `draft.fasta` using as many parallel threads as there are cores on the host machine. In this case the input is a set of Oxford Nanopore 2D reads stored in the `ont_reads.fasta` file and the GraphMap aligner will be used to map them on the draft genome. The output of the scaffolder will consist of 3 files stored in the current working directory:

| Output File                   | Content                                                         |
| ----------------------------: | :-------------------------------------------------------------- |
| example_2.contigs.fasta       | Contigs from the draft genome extended by the scaffolder        |
| example_2.extensions.fasta    | Left and right extensions for each contig in the draft          |
| example_2.scaffolds.fasta     | Final scaffolds created by merging overlapping extended contigs |

## Scripts

Some utility scripts are available in the `/usr/lib/eagler` folder. All scripts have been developed
 and tested with Python 3.4.3.

For detailed usage instructions run the following command for the desired script:

	python3 <script_name>.py --help

### Available scripts:

 1. **genome2contigs**: cuts a reference genome into multiple contigs
 2. **reverse_complement**: performs the reverse complement operation over sequences in a FASTA file
 3. **extension_analysis**: runs various statistics on contig extensions produced by the scaffolder

## Contributors

- [Marko Culinovic](marko.culinovic@gmail.com)
- [Luka Sterbic](luka.sterbic@gmail.com)
- [Mile Sikic](mile.sikic@fer.hr)

[1]: https://github.com/lh3/bwa "Burrows-Wheeler Aligner"
[2]: https://github.com/seqan/seqan "SeqAn Library"
[3]: http://www.stack.nl/~dimitri/doxygen/ "Doxygen"
[4]: http://www.gnu.org/software/make/ "GNU Make"
[5]: https://github.com/mculinovic/cpppoa "cpppoa"
[6]: https://gcc.gnu.org "g++"
[7]: https://github.com/isovic/graphmap "GraphMap Aligner"
